``pulp_container`` Plugin
=========================

.. image:: https://travis-ci.com/pulp/pulp_container.svg?branch=master
    :target: https://travis-ci.com/pulp/pulp_container

This is the ``pulp_container`` Plugin for `Pulp Project
3.0+ <https://pypi.python.org/pypi/pulpcore/>`__. This plugin provides Pulp with support for container
images, similar to the pulp_docker plugin for Pulp 2.

For more information, please see the `documentation
<http://pulp-container.readthedocs.io/en/latest/>`_ or the `Pulp project page
<https://pulpproject.org>`_.
